==> muffin-0.9.2.tar.gz: muffin-0.9.2/src/org/doit/muffin/filter/SecretAgentFilter.java <==
/* $Id: SecretAgentFilter.java,v 1.5 2000/01/24 04:02:21 boyns Exp $ */

/*
 * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
 *
 * This file is part of Muffin.
 *
 * Muffin is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Muffin is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Muffin; see the file COPYING.  If not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package org.doit.muffin.filter;

import org.doit.muffin.*;

public class SecretAgentFilter implements RequestFilter
{
    Prefs prefs;
    SecretAgent factory;

    SecretAgentFilter(SecretAgent factory)
    {
	this.factory = factory;
    }
    
    public void setPrefs(Prefs prefs)
    {
	this.prefs = prefs;
    }
    
    public void filter(Request r) throws FilterException
    {
	String s = prefs.getString("SecretAgent.userAgent");
	if (s.length() > 0)
	{
	    if (s.equalsIgnoreCase("NONE"))
	    {
		r.removeHeaderField("User-Agent");
	    }
	    else
	    {
		r.setHeaderField("User-Agent", s);
	    }
	}
    }
}

==> muffin-0.9.3a.tar.gz: muffin-0.9.3a/src/org/doit/muffin/filter/SecretAgentFilter.java <==
/* $Id: SecretAgentFilter.java,v 1.6 2000/03/30 06:35:16 boyns Exp $ */

/*
 * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
 *
 * This file is part of Muffin.
 *
 * Muffin is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Muffin is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Muffin; see the file COPYING.  If not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package org.doit.muffin.filter;

import org.doit.muffin.*;

public class SecretAgentFilter implements RequestFilter
{
    Prefs prefs;
    SecretAgent factory;

    SecretAgentFilter(SecretAgent factory)
    {
	this.factory = factory;
    }
    
    public void setPrefs(Prefs prefs)
    {
	this.prefs = prefs;
    }
    
    public void filter(Request r) throws FilterException
    {
	String s = prefs.getString("SecretAgent.userAgent");
	if (s.length() > 0)
	{
	    if (s.equalsIgnoreCase("NONE"))
	    {
		r.removeHeaderField("User-Agent");
	    }
	    else
	    {
		r.setHeaderFields("User-Agent", s);
	    }
	}
    }
}
